API reference
=============

.. autofunction:: shufflish.permutation

.. autoclass:: shufflish.Permutations

.. autoclass:: shufflish.AffineCipher

.. autofunction:: shufflish.local_shuffle

.. autodata:: shufflish.PRIMES
